import PyIPSDK
import PyIPSDK.IPSDKIPLArithmetic as arithm
import PyIPSDK.IPSDKIPLBinarization as bin
import PyIPSDK.IPSDKIPLGlobalMeasure as glbmsr
import PyIPSDK.IPSDKIPLIntensityTransform as itrans
import PyIPSDK.IPSDKIPLLogical as logic
import PyIPSDK.IPSDKIPLUtility as util

import numpy as np

def labelToColor(im):

	# Create the ouput image geometry
	geometry = None
	bIs2d = im.getVolumeGeometryType() == PyIPSDK.eVGT_2d
	if bIs2d:
		geometry = PyIPSDK.geometryRgb2d(im.getBufferType(), im.getSizeX(), im.getSizeY())
	else:
		geometry = PyIPSDK.geometryRgb3d(im.getBufferType(), im.getSizeX(), im.getSizeY(), im.getSizeZ())

	# Create the output color image
	imColor = None
	if im.getColorGeometryType() == PyIPSDK.eCGT_Grey :
		imColor = PyIPSDK.createImage(geometry)

		if bIs2d:
			# Copy the channels
			for c in range(0, 3):
				plan = PyIPSDK.extractPlan(0, c, 0, imColor)
				util.copyImg(im, plan)
		else:
			# Copy the channels
			for c in range(0, 3):
				plan = PyIPSDK.extractVolume(c, 0, imColor)
				util.copyImg(im, plan)
	else:
		imColor = util.copyImg(im)

	# Count the number of labels
	statsRes = None
	if bIs2d:
		statsRes = glbmsr.statsMsr2d(im)
	else:
		statsRes = glbmsr.statsMsr3d(im)
	nbLabels = statsRes.max

	# For label images, we create 3 random LUTs (one per channel)
		#2 with values between 50 and 200
	channelValues = np.random.rand(3, int(nbLabels+1))*150+50

	lutR = PyIPSDK.createIntensityLUT(0, 1, channelValues[0, :])
	lutG = PyIPSDK.createIntensityLUT(0, 1, channelValues[1, :])
	lutB = PyIPSDK.createIntensityLUT(0, 1, channelValues[2, :])

	# The background is set to 0
	lutR.lookupTable[0] = 0
	lutG.lookupTable[0] = 0
	lutB.lookupTable[0] = 0

	# Special case for binary image : we only  use a blue color for value 1
	if im.getBufferType() == PyIPSDK.eIBT_Binary:
		lutR.lookupTable[1] = 0
		lutG.lookupTable[1] = 0
		lutB.lookupTable[1] = 200
	
	colorLut = [lutR, lutG, lutB]

	# Convert the label image to a color image
	if bIs2d:
		for c in range(0, 3):
			plan = PyIPSDK.extractPlan(0, c, 0, imColor)
			itrans.lutTransform2dImg(im, colorLut[c], plan)
	else:
		for c in range(0, 3):
			plan = PyIPSDK.extractVolume(c, 0, imColor)
			itrans.lutTransform3dImg(im, colorLut[c], plan)

	imColor = util.convertImg(imColor, PyIPSDK.eIBT_UInt8)
	return imColor

